"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UartListener = void 0;
const serialport_1 = __importDefault(require("serialport"));
const parser_readline_1 = __importDefault(require("@serialport/parser-readline"));
const ajaxSerialMessage_1 = require("./ajaxSerialMessage");
const ajax_1 = require("./ajax");
const stream_1 = require("stream");
const SERIAL_DEVICE_NAME = '/dev/serial0';
const BAUD_RATE = 57600;
class UartListener {
    constructor(log) {
        this.log = log;
        this._observers = {};
        const serialPort = new serialport_1.default(SERIAL_DEVICE_NAME, { baudRate: BAUD_RATE }, (err) => {
            if (err) {
                this.log.error('Unable to open serial port: ' + err);
            }
            else {
                this.log.debug(`Serial port open: ${SERIAL_DEVICE_NAME}, rate=${BAUD_RATE}`);
            }
        });
        const processMessage = new stream_1.Transform({
            readableObjectMode: true,
            transform(chunk, encoding, callback) {
                const msg = (0, ajaxSerialMessage_1.ajaxMessageFromString)(chunk.toString());
                if (msg.messageType !== ajax_1.AjaxSerialMessageType.UNKNOWN) {
                    log.debug(`MSG: ${msg}`);
                    this.push(msg);
                }
                else {
                    log.debug(`Message skipped: ${chunk.toString()}`);
                }
                callback();
            },
        });
        serialPort.pipe(new parser_readline_1.default({ delimiter: '\r\n', encoding: 'ascii' }))
            .pipe(processMessage)
            .on('data', (msg) => {
            log.debug(`Calling observers for message ${msg.messageType}`);
            if (msg.deviceId in this._observers) {
                this._observers[msg.deviceId](msg);
            }
            else {
                log.debug(`Nothing wanted to nandle a message. No observers found. MSG: ${msg}`);
            }
        });
    }
    static instance(logger) {
        return this._instance || (this._instance = new this(logger));
    }
    registerObserverForDevice(deviceId, observer) {
        this._observers[deviceId] = observer;
        this.log.debug(`Serial port observer added for device id ${deviceId}`);
    }
}
exports.UartListener = UartListener;
//# sourceMappingURL=uartListener.js.map